(window.webpackJsonp=window.webpackJsonp||[]).push([[24],{251:function(e,r,n){"use strict";n.r(r),r.default={colorRules:{colorRequired:"Farbe wird benötigt"},labelNameRules:{labelRequired:"Labelname wird benötigt",labelLessThan100Chars:"Labelname muss kürzer als 100 Zeichen sein"},userNameRules:{userNameRequired:"Benutzername wird benötigt",userNameLessThan30Chars:"Benutzername muss kürzer als 30 Zeichen sein"},roleRules:{roleRequired:"Rolle wird benötigt"},projectNameRules:{projectNameRequired:"Projektname wird benötigt",projectNameLessThan30Chars:"Projektname muss kürzer als 30 Zeichen sein"},descriptionRules:{descriptionRequired:"Beschreibung wird benötigt",descriptionLessThan30Chars:"Beschreibung muss kürzer als 100 Zeichen sein"},projectTypeRules:{projectTypeRequired:"Projekttyp wird benötigt"},fileFormatRules:{fileFormatRequired:"Dateiformat wird benötigt"},uploadFileRules:{fileRequired:"Datei(en) werden benötigt",fileLessThan1MB:"Dateigröße muss kleiner als 1 MB sein!"},passwordRules:{passwordRequired:"Passwort wird benötigt",passwordLessThan30Chars:"Passwort muss kürzer als 30 Zeichen sein"}}}}]);