(window.webpackJsonp=window.webpackJsonp||[]).push([[33],{273:function(e,t,o){"use strict";o.r(t),t.default={dataset:"Dataset",actions:"Actions",importDataset:"Import Dataset",exportDataset:"Export Dataset",text:"Text",metadata:"Metadata",action:"Action",annotate:"Annotate",importDataTitle:"Upload Data",importDataMessage1:"Select a file format",importDataMessage2:"Select file(s)",importDataPlaceholder:"File input",exportDataTitle:"Export Data",exportDataMessage:"Select a file format",exportDataMessage2:"Select a file name",deleteDocumentsTitle:"Delete Document",deleteDocumentsMessage:"Are you sure you want to delete these documents from this project?",deleteBulkDocumentsTitle:"Delete All Documents",deleteBulkDocumentsMessage:"Are you sure you want to delete all documents from this project?",pageText:"{0}-{1} of {2}"}}}]);