(window.webpackJsonp=window.webpackJsonp||[]).push([[57],{298:function(t,e,o){"use strict";o.r(e),e.default={statistics:"Statistiques",progress:["Complété","Incomplet"],labelStats:"Étiqueter les stats",userStats:"Stats des utilisateurs"}}}]);