# Generated by Django 3.1.6 on 2021-03-01 03:02

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('api', '0006_merge_20210221_1258'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='rolemapping',
            unique_together={('user', 'project')},
        ),
    ]
