(window.webpackJsonp=window.webpackJsonp||[]).push([[4],{195:function(e,n,o){"use strict";o.r(n),n.default={locales:[{name:"English",code:"en",iso:"en-CA",file:"en"},{name:"中文",code:"zh",iso:"zh-CN",file:"zh"},{name:"Français",code:"fr",iso:"fr-CA",file:"fr"},{name:"Deutsch",code:"de",iso:"de-DE",file:"de"}],lazy:!0,langDir:"i18n/",defaultLocale:"en",vueI18n:{fallbackLocale:"en"},detectBrowserLanguage:{useCookie:!0,cookieKey:"i18n_redirected",onlyOnRoot:!0}}}}]);