(window.webpackJsonp=window.webpackJsonp||[]).push([[90],{331:function(e,t,c){"use strict";c.r(t),t.default={createProjectTitle:"添加项目",projectName:"项目名称",projectType:"项目类型",textClassification:"文本分类",sequenceLabeling:"序列标注",sequenceToSequence:"序列到序列",randomizeDocOrder:"随机文档顺序",shareAnnotations:"在所有用户共享标注",delete:"删除",deleteProjectTitle:"删除项目",deleteProjectMessage:"你确定要删除这些项目吗？",search:"搜索",projectTypes:["文本分类","序列标注","序列到序列"]}}}]);