(window.webpackJsonp=window.webpackJsonp||[]).push([[48],{285:function(e,t,n){"use strict";n.r(t),t.default={mainTitle:"Annotation de texte pour les humains",getStarted:"Démarrer",startAnnotation:"Commencer Annotation",featuresTitle:"Les meilleures caractéristiques",featuresTitle1:"Collaboration des équipes",featuresText1:"Annotation avec vos coéquipiers",featuresTitle2:"Toute langue",featuresText2:"Annotation dans n'importe quelle langue",featuresTitle3:"Source ouverte",featuresText3:"Annotation gratuite et personnalisable",footerTitle:"Réalisez vos idées rapidement",demoDropDown:"Essayer la démo",demoNER:"Reconnaissance de l'entité désignée",demoSent:"Analyse du sentiment",demoTranslation:"Traduction",demoTextToSQL:"Texte à SQL"}}}]);