# Generated by Django 2.1.7 on 2020-06-12 02:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_speech2text'),
        ('api', '0002_project_single_class_classification'),
    ]

    operations = [
    ]
