(window.webpackJsonp=window.webpackJsonp||[]).push([[60],{288:function(n,o,e){"use strict";e.r(o),o.default={login:"Connexion",signOut:"Déconnexion",username:"Nom d'utilisateur",password:"Mot de passe"}}}]);