(window.webpackJsonp=window.webpackJsonp||[]).push([[20],{260:function(e,l,t){"use strict";t.r(l),l.default={labels:"Labels",shortkey:"Tastenkürzel",color:"Farbe",createLabel:"Erstelle Label",importLabels:"Importiere Labels",exportLabels:"Exportiere Labels",labelName:"Labelname",labelMessage:"Labelname wird benötigt",key:"Schlüssel",deleteLabel:"Lösche Label",deleteMessage:"Bist du dir sicher, dass du diese Labels aus dem Projekt löschen willst?",importTitle:"Label hochladen",importMessage1:"Beispielformat",importMessage2:"Wähle eine Datei",filePlaceholder:"Eingabe einer Datei"}}}]);