(window.webpackJsonp=window.webpackJsonp||[]).push([[41],{281:function(t,e,o){"use strict";o.r(e),e.default={statistics:"Statistics",progress:["Completed","Incomplete"],labelStats:"Label stats",userStats:"User stats"}}}]);