(window.webpackJsonp=window.webpackJsonp||[]).push([[71],{311:function(e,l,o){"use strict";o.r(l),l.default={labels:"标签",shortkey:"短键",color:"颜色",createLabel:"创建标签",importLabels:"导入标签",exportLabels:"导出标签",labelName:"标签名",labelMessage:"请输入标签名",key:"键",deleteLabel:"删除标签",deleteMessage:"你确定要从这个项目中删除这些标签吗",importTitle:"导入标签",importMessage1:"样例格式",importMessage2:"请选择一个文件",filePlaceholder:"输入文件"}}}]);