(window.webpackJsonp=window.webpackJsonp||[]).push([[46],{283:function(e,r,t){"use strict";t.r(r),r.default={continue:"Continuer",yes:"Oui",all:"Tout",save:"Enregistrer",edit:"Éditer",create:"Créer",cancel:"Annuler",close:"Fermer",upload:"Télécharger",add:"Ajouter",delete:"Supprimer",search:"Recherchez",name:"Nom",import:"Importer",export:"Exporter",description:"Description",type:"Type",loading:"Chargement... veuillez patienter"}}}]);