(window.webpackJsonp=window.webpackJsonp||[]).push([[83],{324:function(e,t,o){"use strict";o.r(t),t.default={checkedTooltip:"已选",notCheckedTooltip:"未选",selectFilterTooltip:"过滤",filterOption1:"全部",filterOption2:"已标注",filterOption3:"未标注",guidelineTooltip:"显示指南",guidelinePopupTitle:"标注指南",metadataDefaultMessage:"没有数据可获得",key:"键",value:"值",newText:"下一条"}}}]);