(window.webpackJsonp=window.webpackJsonp||[]).push([[34],{274:function(e,o,n){"use strict";n.r(o),o.default={fileCannotUpload:"The file(s) could not be uploaded. Maybe invalid format.\n Please check available formats and the following file(s): ",labelCannotCreate:"The label could not be created.\n You cannot use the same label name or shortcut key.",invalidUserOrPass:"Incorrect username or password, or something went wrong."}}}]);