# Generated by Django 3.1.6 on 2021-02-21 12:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0005_auto_20210201_0603'),
        ('api', '0005_auto_20210120_1730'),
    ]

    operations = [
    ]
