(window.webpackJsonp=window.webpackJsonp||[]).push([[62],{299:function(e,n,o){"use strict";o.r(n),n.default={continue:"继续",yes:"是",all:"全部",save:"保存",edit:"编辑",create:"创建",cancel:"取消",close:"关闭",upload:"上传",add:"增加",delete:"删除",search:"搜索",name:"名称",import:"导入",export:"导出",description:"描述",type:"类型",loading:"加载中... 请等待"}}}]);