(window.webpackJsonp=window.webpackJsonp||[]).push([[23],{263:function(t,e,n){"use strict";n.r(e),e.default={statistics:"Statistiken",progress:["Abgeschlossen","Unvollständig"],labelStats:"Labelstatistiken",userStats:"Nutzerstatistiken"}}}]);