(window.webpackJsonp=window.webpackJsonp||[]).push([[107],{1109:function(t,e,n){"use strict";n.r(e);var o={layout:"project",data:function(){return{e6:1,items:[{title:this.$t("projectHome.importData"),videoId:"dA4ID1DSxCE"},{title:this.$t("projectHome.createLabels"),videoId:"1bSML270quU"},{title:this.$t("projectHome.addMembers"),videoId:"NI09dcBz-qA"},{title:this.$t("projectHome.defineGuideline"),videoId:"AvvX3Xs32nA"},{title:this.$t("projectHome.annotateDataset"),videoId:"F3XoSdyiMhA"},{title:this.$t("projectHome.viewStatistics"),videoId:"kfRpa0mNQMY"},{title:this.$t("projectHome.exportDataset"),videoId:"Pfy_QcHEeQ4"}]}},methods:{next:function(){this.e6=Math.max(1,(this.e6+1)%(this.items.length+1))},prev:function(){this.e6=Math.max(1,this.e6-1)}},validate:function(t){var e=t.params;return/^\d+$/.test(e.id)}},r=n(27),c=n(31),d=n.n(c),l=n(193),v=n(508),m=n(491),h=n(581),_=n(584),f=n(585),component=Object(r.a)(o,(function(){var t=this,e=t.$createElement,n=t._self._c||e;return n("v-card",[n("v-card-title",[t._v("\n    "+t._s(t.$t("projectHome.welcome"))+"\n  ")]),t._v(" "),n("v-stepper",{attrs:{vertical:"","non-linear":""},model:{value:t.e6,callback:function(e){t.e6=e},expression:"e6"}},t._l(t.items,(function(e,o){return n("div",{key:o},[n("v-stepper-step",{attrs:{complete:t.e6>o+1,step:o+1,editable:""}},[t._v("\n        "+t._s(e.title)+"\n      ")]),t._v(" "),n("v-stepper-content",{attrs:{step:o+1}},[t.e6===o+1?n("v-card",{staticClass:"mb-12",attrs:{width:"560",height:"315"}},[n("youtube",{ref:"youtube",refInFor:!0,attrs:{"video-id":e.videoId}})],1):t._e(),t._v(" "),n("v-btn",{attrs:{color:"primary mt-5"},on:{click:t.next}},[t._v("\n          "+t._s(t.$t("generic.continue"))+"\n        ")]),t._v(" "),n("v-btn",{staticClass:"mt-5",attrs:{text:""},on:{click:t.prev}},[t._v("\n          "+t._s(t.$t("generic.cancel"))+"\n        ")])],1)],1)})),0)],1)}),[],!1,null,null,null);e.default=component.exports;d()(component,{VBtn:l.a,VCard:v.a,VCardTitle:m.c,VStepper:h.a,VStepperContent:_.a,VStepperStep:f.a})}}]);