(window.webpackJsonp=window.webpackJsonp||[]).push([[9,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95],{153:function(e,t,r){"use strict";r.r(t);var o=r(319),l=r(318),n=r(317),d=r(320),c=r(321),f=r(322),m=r(323),T=r(324),h=r(325),R=r(326),D=r(327),w=r(328),x=r(329),M=r(330),j=r(331),L=r(332);t.default={home:o.default,header:l.default,generic:n.default,rules:d.default,toastui:c.default,user:f.default,vuetify:m.default,annotation:T.default,dataset:h.default,errors:R.default,guideline:D.default,projectHome:w.default,labels:x.default,members:M.default,overview:j.default,statistics:L.default}},317:function(e,t,r){"use strict";r.r(t),t.default={continue:"继续",yes:"是",all:"全部",save:"保存",edit:"编辑",create:"创建",cancel:"取消",close:"关闭",upload:"上传",add:"增加",delete:"删除",search:"搜索",name:"名称",import:"导入",export:"导出",description:"描述",type:"类型",loading:"加载中... 请等待"}},318:function(e,t,r){"use strict";r.r(t),t.default={projects:"项目"}},319:function(e,t,r){"use strict";r.r(t),t.default={mainTitle:"让文本标注服务人类",getStarted:"快速开始",startAnnotation:"开始标注",featuresTitle:"功能特性",featuresTitle1:"团队合作",featuresText1:"与你的团队标注",featuresTitle2:"任何语言",featuresText2:"用任何语言标注",featuresTitle3:"免费开源",featuresText3:"标注免费可自定义",footerTitle:"尽快实现你的想法",demoDropDown:"试一试",demoNER:"命名实体识别",demoSent:"情感分析",demoTranslation:"文本翻译",demoTextToSQL:"语义解析Text-to-SQL"}},320:function(e,t,r){"use strict";r.r(t),t.default={colorRules:{colorRequired:"请输入颜色"},labelNameRules:{labelRequired:"请输入名称",labelLessThan30Chars:"名称必须少于30个字符"},userNameRules:{userNameRequired:"请输入用户名",userNameLessThan30Chars:"用户名必须少于30个字符"},roleRules:{roleRequired:"请输入角色"},projectNameRules:{projectNameRequired:"请输入项目名称",projectNameLessThan30Chars:"项目名称必须少于30个字符"},descriptionRules:{descriptionRequired:"请输入描述",descriptionLessThan30Chars:"描述必须少于100个字符"},projectTypeRules:{projectTypeRequired:"请输入项目类型"},fileFormatRules:{fileFormatRequired:"请输入文件类型"},uploadFileRules:{fileRequired:"请输入文件",fileLessThan1MB:"文件大小必须小于 1 MB!"},passwordRules:{passwordRequired:"请输入密码",passwordLessThan30Chars:"密码必须小于30个字符"}}},321:function(e,t,r){"use strict";r.r(t),t.default={localeCode:"zh_CN"}},322:function(e,t,r){"use strict";r.r(t),t.default={login:"登录",signOut:"注销",username:"用户名",password:"密码"}},323:function(e,t,r){"use strict";r.r(t),t.default={itemsPerPageText:"每页最多可显示",noDataAvailable:"没有数据可获得"}},324:function(e,t,r){"use strict";r.r(t),t.default={checkedTooltip:"已选",notCheckedTooltip:"未选",selectFilterTooltip:"过滤",filterOption1:"全部",filterOption2:"已标注",filterOption3:"未标注",guidelineTooltip:"显示指南",guidelinePopupTitle:"标注指南",metadataDefaultMessage:"没有数据可获得",key:"键",value:"值",newText:"下一条"}},325:function(e,t,r){"use strict";r.r(t),t.default={dataset:"数据集",actions:"操作",importDataset:"导入数据集",exportDataset:"导出数据集",text:"文本",metadata:"元数据",action:"操作",annotate:"标注",importDataTitle:"上传数据",importDataMessage1:"选择文件格式",importDataMessage2:"选择一个文件",importDataPlaceholder:"请导入文件",exportDataTitle:"导出数据",exportDataMessage:"请选择文件格式",deleteDocumentsTitle:"删除文档",deleteDocumentsMessage:"你确定要从这个项目中删除这些文档吗？",pageText:"{0}-{1} of {2}"}},326:function(e,t,r){"use strict";r.r(t),t.default={fileCannotUpload:"这个文件不能被上传，获取格式错误，请仔细检查文件格式",labelCannotCreate:"这个标签不能被创建，你可能在其它的键上用了相同的标签名",invalidUserOrPass:"用户名或者密码不正确"}},327:function(e,t,r){"use strict";r.r(t),t.default={guideline:"指南",writeGuidelinePrompt:"请写入标注指南"}},328:function(e,t,r){"use strict";r.r(t),t.default={home:"主页",welcome:"欢迎进入数据标注平台",importData:"导入数据集",createLabels:"为这个项目创建标签名",addMembers:"添加成员",defineGuideline:"定义指南",annotateDataset:"标注数据集",viewStatistics:"查看统计",exportDataset:"导出数据集"}},329:function(e,t,r){"use strict";r.r(t),t.default={labels:"标签",shortkey:"键",color:"颜色",createLabel:"创建标签",importLabels:"创建标签",exportLabels:"导出标签",labelName:"标签名",labelMessage:"请输入标签名",key:"Key",deleteLabel:"删除标签",deleteMessage:"你确定要从这个项目中删除这些标签吗",importTitle:"导入标签",importMessage1:"样例格式",importMessage2:"请选择一个文件",filePlaceholder:"输入文件"}},330:function(e,t,r){"use strict";r.r(t),t.default={members:"成员",role:"角色",updateRole:"更行角色",addMember:"添加成员",userSearchAPIs:"用户搜索接口",userSearchPrompt:"开始搜索",removeMember:"移除成员",removePrompt:"你确定要移除当前成员吗?",roles:{projectAdmin:"项目管理员",annotator:"标注员",annotationApprover:"审查员",undefined:"角色未定义"}}},331:function(e,t,r){"use strict";r.r(t),t.default={createProjectTitle:"添加项目",projectName:"项目名称",projectType:"项目类型",textClassification:"文本分类",sequenceLabeling:"序列标注",sequenceToSequence:"序列到序列",randomizeDocOrder:"随机文档顺序",shareAnnotations:"在所有用户共享标注",delete:"删除",deleteProjectTitle:"删除项目",deleteProjectMessage:"你确定要删除这些项目吗？",search:"搜索",projectTypes:["文本分类","序列标注","序列到序列"]}},332:function(e,t,r){"use strict";r.r(t),t.default={statistics:"统计",progress:["已完成","未完成"],labelStats:"标签统计",userStats:"用户统计"}}}]);