(window.webpackJsonp=window.webpackJsonp||[]).push([[55],{296:function(e,r,t){"use strict";t.r(r),r.default={members:"Membres",role:"Rôle",updateRole:"Mettre à jour le rôle",addMember:"Ajouter un membre",userSearchAPIs:"Rechercher des utilisateurs (avec l'IPA)",userSearchPrompt:"Commencez à taper pour rechercher",removeMember:"Supprimer un membre",removePrompt:"Êtes-vous sûr de vouloir supprimer ces membres ?",roles:{projectAdmin:"L'administrateur du projet",annotator:"Étiqueteuse",annotationApprover:"Approbateur d'étiquettes",undefined:"Aucun rôle défini"}}}}]);