(window.webpackJsonp=window.webpackJsonp||[]).push([[38],{278:function(e,o,r){"use strict";r.r(o),o.default={members:"Members",role:"Role",updateRole:"Update Role",addMember:"Add Member",userSearchAPIs:"User Search APIs",userSearchPrompt:"Start typing to search",removeMember:"Remove Member",removePrompt:"Are you sure you want to remove these members?",roles:{projectAdmin:"Project Admin",annotator:"Annotator",annotationApprover:"Annotation Approver",undefined:"No Role Defined"}}}}]);