# Generated by Django 2.1.11 on 2019-12-06 08:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='single_class_classification',
            field=models.BooleanField(default=False),
        ),
    ]
