(window.webpackJsonp=window.webpackJsonp||[]).push([[84],{325:function(t,e,o){"use strict";o.r(e),e.default={dataset:"数据集",actions:"操作",importDataset:"导入数据集",exportDataset:"导出数据集",text:"文本",metadata:"元数据",action:"操作",annotate:"标注",importDataTitle:"上传数据",importDataMessage1:"选择文件格式",importDataMessage2:"选择一个文件",importDataPlaceholder:"请导入文件",exportDataTitle:"导出数据",exportDataMessage:"请选择文件格式",deleteDocumentsTitle:"删除文档",deleteDocumentsMessage:"你确定要从这个项目中删除这些文档吗？",pageText:"{0}-{1} of {2}"}}}]);