{% extends "base_auth.html" %}

{% block content_auth %}
<div class="card-content">
  <p>
    Your password has been set. You may go ahead and <a href="{% url 'login' %}">sign in</a> now.
  </p>
</div>
{% endblock %}
