# Generated by Django 3.1.5 on 2021-01-14 11:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_comment'),
        ('api', '0003_merge_20200612_0205'),
    ]

    operations = [
    ]
