(window.webpackJsonp=window.webpackJsonp||[]).push([[106],{1056:function(e,t,r){"use strict";var n=r(593);r.n(n).a},1057:function(e,t,r){(t=r(23)(!1)).push([e.i,".te-md-container .CodeMirror,.tui-editor-contents{font-size:20px}",""]),e.exports=t},1110:function(e,t,r){"use strict";r.r(t);r(13);var n=r(0),o=r(186),c=r.n(o),d=(r(800),r(560),r(806),r(561)),l=(r(534),{layout:"project",components:{Editor:d.Editor},data:function(){return{editorOptions:{language:this.$t("toastui.localeCode")},project:{}}},watch:{"project.guideline":function(){this.updateProject()}},created:function(){var e=this;return Object(n.a)(regeneratorRuntime.mark((function t(){var r;return regeneratorRuntime.wrap((function(t){for(;;)switch(t.prev=t.next){case 0:return r=e.$route.params.id,t.next=3,e.$services.project.findById(r);case 3:e.project=t.sent;case 4:case"end":return t.stop()}}),t)})))()},methods:{updateProject:c.a.debounce((function(){this.$services.project.update(this.project)}),1e3)},validate:function(e){var t=e.params;return/^\d+$/.test(t.id)}}),f=(r(1056),r(27)),component=Object(f.a)(l,(function(){var e=this,t=e.$createElement;return(e._self._c||t)("editor",{attrs:{"preview-style":"vertical",height:"inherit",options:e.editorOptions},model:{value:e.project.guideline,callback:function(t){e.$set(e.project,"guideline",t)},expression:"project.guideline"}})}),[],!1,null,null,null);t.default=component.exports},593:function(e,t,r){var content=r(1057);"string"==typeof content&&(content=[[e.i,content,""]]),content.locals&&(e.exports=content.locals);(0,r(24).default)("10ecfcfc",content,!0,{sourceMap:!1})}}]);