(window.webpackJsonp=window.webpackJsonp||[]).push([[28],{265:function(e,t,l){"use strict";l.r(t),t.default={continue:"Continue",yes:"Yes",all:"All",save:"Save",edit:"Edit",create:"Create",cancel:"Cancel",close:"Close",upload:"Upload",add:"Add",delete:"Delete",deleteAll:"Delete All",search:"Search",name:"Name",import:"Import",export:"Export",description:"Description",type:"Type",loading:"Loading... Please wait"}}}]);