(window.webpackJsonp=window.webpackJsonp||[]).push([[22],{262:function(e,n,t){"use strict";t.r(n),n.default={createProjectTitle:"Projekt hinzufügen",projectName:"Projektname",projectType:"Projekttyp",textClassification:"Textklassifikation",sequenceLabeling:"Sequenz-Labeling",sequenceToSequence:"Sequenz zu Sequenz",randomizeDocOrder:"Dokumentenreihenfolge zufällig wählen",shareAnnotations:"Gemeinsame Annotationen für Nutzer",delete:"Löschen",deleteProjectTitle:"Lösche Projekt",deleteProjectMessage:"Bist du dir sicher, dass du diese Projekte löschen willst?",search:"Suchen",projectTypes:["Textklassifikation","Sequenz-Labeling","Sequenz zu Sequenz"]}}}]);