(window.webpackJsonp=window.webpackJsonp||[]).push([[50],{291:function(e,t,n){"use strict";n.r(t),t.default={dataset:"Ensemble de données",actions:"Actions",importDataset:"Importer l'ensemble de données",exportDataset:"Exporter l'ensemble de données",text:"Texte",metadata:"Métadonnées",action:"Action",annotate:"Annotater",importDataTitle:"Télécharger les données",importDataMessage1:"Sélectionnez un format de fichier",importDataMessage2:"Sélectionnez un fichier",importDataPlaceholder:"Saisir un fichier",exportDataTitle:"Exporter les données",exportDataMessage:"Sélectionnez un format de fichier",deleteDocumentsTitle:"Supprimer le document",deleteDocumentsMessage:"Êtes-vous sûr de vouloir supprimer ces documents de ce projet ?",pageText:"{0}-{1} de {2}"}}}]);