(window.webpackJsonp=window.webpackJsonp||[]).push([[14],{255:function(e,t,l){"use strict";l.r(t),t.default={checkedTooltip:"Geprüft",notCheckedTooltip:"Nicht geprüft",selectFilterTooltip:"Wähle einen Filter",filterOption1:"Alle",filterOption2:"Erledigt",filterOption3:"Unerledigt",guidelineTooltip:"Zeige Leitfaden",guidelinePopupTitle:"Annotationsleitfaden",metadataDefaultMessage:"Keine Daten verfügbar",key:"Schlüssel",value:"Wert",newText:"Neuer Text"}}}]);