(window.webpackJsonp=window.webpackJsonp||[]).push([[37],{277:function(e,l,t){"use strict";t.r(l),l.default={labels:"Labels",shortkey:"Shortkey",color:"Color",createLabel:"Create Label",importLabels:"Import Labels",exportLabels:"Export Labels",labelName:"Label name",labelMessage:"Label name is required",key:"Key",deleteLabel:"Delete Label",deleteMessage:"Are you sure you want to delete these labels from this project?",importTitle:"Upload Label",importMessage1:"Example format",importMessage2:"Select a file",filePlaceholder:"File input"}}}]);