(window.webpackJsonp=window.webpackJsonp||[]).push([[72],{312:function(e,r,o){"use strict";o.r(r),r.default={members:"成员",role:"角色",updateRole:"更行角色",addMember:"添加成员",userSearchAPIs:"用户搜索接口",userSearchPrompt:"开始搜索",removeMember:"移除成员",removePrompt:"你确定要移除当前成员吗?",roles:{projectAdmin:"项目管理员",annotator:"标注员",annotationApprover:"审查员",undefined:"角色未定义"}}}}]);