(window.webpackJsonp=window.webpackJsonp||[]).push([[21],{261:function(e,r,n){"use strict";n.r(r),r.default={members:"Mitglieder",role:"Rolle",updateRole:"Rolle aktualisieren",addMember:"Mitglied hinzufügen",userSearchAPIs:"Nutzer-Such-APIs",userSearchPrompt:"Tippe, um zu suchen",removeMember:"Mitglied entfernen",removePrompt:"Bist du dir sicher, dass du diese Mitglieder entfernen willst?",roles:{projectAdmin:"Projektadministrator",annotator:"Annotator",annotationApprover:"Annotationsmoderator",undefined:"Keine Rolle definiert"}}}}]);