(window.webpackJsonp=window.webpackJsonp||[]).push([[56],{297:function(e,t,o){"use strict";o.r(t),t.default={createProjectTitle:"Ajouter un projet",projectName:"Nom du projet",projectType:"Type de projet",textClassification:"Classification des textes",sequenceLabeling:"Étiquetage des séquences",sequenceToSequence:"Séquence à séquence",randomizeDocOrder:"Randomiser l'ordre des documents",shareAnnotations:"Partager les annotations entre tous les utilisateurs",deleteProjectTitle:"Supprimer le projet",deleteProjectMessage:"Êtes-vous sûr de vouloir supprimer ces projets ?",projectTypes:["Classification des textes","Étiquetage des séquences","Séquence à séquence"]}}}]);