{% extends "base_auth.html" %}

{% block content_auth %}
{% if validlink %}
<div class="card-content">
  <div style="text-align:center;font-size:1.5em">
    <h2>Change password</h2>
  </div>

  <form method="post">
    {% csrf_token %}
    {{ form.as_p }}
    <div style="text-align:center">
      <button type="submit" class="button is-link">Change password</button>
    </div>
  </form>

</div>
{% else %}
<div class="card-content">
  The password reset link was invalid, possibly because it has already been used.
  Please request a new password reset.
</div>
{% endif %}
{% endblock %}
