{% extends "base_auth.html" %}

{% block content_auth %}
<div class="card-content">
  <p>
    The webmaster <span>has not set up any emails</span> yet, so we can't send you any link confirmation
  </p>
  <p>
    Please contact the admin to learn more
  </p>
</div>
{% endblock %}
