{% extends "base_auth.html" %}

{% load widget_tweaks %}
{% block content_auth %}
<div class="card-content">
  <div style="text-align:center;font-size:1.5em">
    <h2>Forgot password</h2>
  </div>

  <form method="post">
    {% csrf_token %}
    {{ form.as_p }}
    <div style="text-align:center">
      <button type="submit" class="button is-link">Submit</button>
    </div>
  </form>

</div>
{% endblock %}
