{% extends "base.html" %}
{% load static %}
{% load render_bundle from webpack_loader %}
{% load widget_tweaks %}
{% block content %}
<div id="projects_root"></div>
{% endblock %}
{% block footer %}
{% render_bundle 'projects' 'js' %}
{% endblock %}
