(window.webpackJsonp=window.webpackJsonp||[]).push([[39],{280:function(e,t,o){"use strict";o.r(t),t.default={createProjectTitle:"Add Project",projectName:"Project name",projectType:"Project type",textClassification:"Text Classification",sequenceLabeling:"Sequence Labeling",sequenceToSequence:"Sequence to sequence",randomizeDocOrder:"Randomize document order",shareAnnotations:"Share annotations across all users",delete:"Delete",deleteProjectTitle:"Delete Project",deleteProjectMessage:"Are you sure you want to delete these projects?",search:"Search",projectTypes:["Text Classification","Sequence Labeling","Sequence to sequence"]}}}]);