(window.webpackJsonp=window.webpackJsonp||[]).push([[31],{272:function(e,t,o){"use strict";o.r(t),t.default={checkedTooltip:"Checked",notCheckedTooltip:"Not Checked",selectFilterTooltip:"Select a Filter",filterOption1:"All",filterOption2:"Done",filterOption3:"Undone",guidelineTooltip:"Show Guideline",guidelinePopupTitle:"Annotation Guideline",commentTooltip:"Click to comment on document",commentPopupTitle:"Comment",metadataDefaultMessage:"No data available",key:"Key",value:"Value",newText:"New text"}}}]);