(window.webpackJsonp=window.webpackJsonp||[]).push([[101],{1107:function(t,n,e){"use strict";e.r(n);e(28),e(528),e(113);var o=e(500),r={layout:"demo",components:{Seq2seqBox:e(563).a,ListMetadata:o.a},data:function(){return{currentDoc:{id:8,text:"SELECT count(*) FROM head WHERE age  >  56",annotations:[{id:17,text:"How many heads of the departments are older than 56 ?",user:1,document:8}],meta:'{"department.department_id": "INT", "department.name": "CHAR", "department.num_employee": "INT", "head.head_id": "INT", "head.name": "INT", "head.age": "INT", "management.department_id": "INT", "management.head_id": "INT", "management.temporary_acting": "VARCHAR"}',annotation_approver:null}}},methods:{_deleteAnnotation:function(t){this.currentDoc.annotations=this.currentDoc.annotations.filter((function(n){return n.id!==t}))},_updateAnnotation:function(t,text){var n=this.currentDoc.annotations.findIndex((function(n){return n.id===t}));this.currentDoc.annotations[n].text=text},_createAnnotation:function(text){var t={id:Math.floor(Math.random()*Math.floor(Number.MAX_SAFE_INTEGER)),text:text};this.currentDoc.annotations.push(t)}}},c=e(27),d=e(31),m=e.n(d),l=e(508),_=e(491),h=e(509),f=e(482),v=e(488),x=e(510),component=Object(c.a)(r,(function(){var t=this,n=t.$createElement,e=t._self._c||n;return e("v-main",[e("v-container",{attrs:{fluid:""}},[e("v-row",{attrs:{justify:"center"}},[e("v-col",{attrs:{cols:"12",md:"9"}},[e("v-card",{staticClass:"title mb-5"},[e("v-card-text",{staticClass:"title"},[t._v("\n            "+t._s(t.currentDoc.text)+"\n          ")])],1),t._v(" "),e("seq2seq-box",{attrs:{text:t.currentDoc.text,annotations:t.currentDoc.annotations},on:{"delete:annotation":t._deleteAnnotation,"update:annotation":t._updateAnnotation,"create:annotation":t._createAnnotation}})],1),t._v(" "),e("v-col",{attrs:{cols:"12",md:"3"}},[e("list-metadata",{attrs:{metadata:JSON.parse(t.currentDoc.meta)}})],1)],1)],1)],1)}),[],!1,null,null,null);n.default=component.exports;m()(component,{VCard:l.a,VCardText:_.b,VCol:h.a,VContainer:f.a,VMain:v.a,VRow:x.a})},528:function(t,n,e){var o=e(26);o(o.S,"Number",{MAX_SAFE_INTEGER:9007199254740991})}}]);