(window.webpackJsonp=window.webpackJsonp||[]).push([[54],{295:function(e,t,r){"use strict";r.r(t),t.default={labels:"Étiquettes",shortkey:"Raccourci clavier",color:"Couleur",createLabel:"Créer un label",importLabels:"Importer des étiquettes",exportLabels:"Exporter des étiquettes",labelName:"Nom de l'étiquette",labelMessage:"Le nom de l'étiquette est obligatoire",key:"Clé",deleteLabel:"Supprimer l'étiquette",deleteMessage:"Êtes-vous sûr de vouloir supprimer ces étiquettes de ce projet ?",importTitle:"Télécharger l'étiquette",importMessage1:"Exemple de format",importMessage2:"Sélectionnez un fichier",filePlaceholder:"Saisir un fichier"}}}]);