(window.webpackJsonp=window.webpackJsonp||[]).push([[11],{248:function(e,n,t){"use strict";t.r(n),n.default={continue:"Weiter",yes:"Ja",all:"Alle",save:"Speichern",edit:"Editieren",create:"Erstellen",cancel:"Abbrechen",close:"Schließen",upload:"Hochladen",add:"Hinzufügen",delete:"Löschen",search:"Suchen",name:"Name",import:"Importieren",export:"Exportieren",description:"Beschreibung",type:"Typ",loading:"Laden... bitte warten"}}}]);