{% extends "base.html" %}
{% load static %}
{% load render_bundle from webpack_loader %}
{% block header %}
<link rel="stylesheet" href="{% static 'assets/css/admin.css' %}">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/9.12.0/styles/vs2015.min.css">
{% endblock %}
{% block navigation %}
<a class="navbar-item" href="{% url 'annotation' view.kwargs.project_id %}">
  <span class="icon">
    <i class="fas fa-user-edit"></i>
  </span>
  <b>Annotate Data</b>
</a>
<a class="navbar-item" href="{% url 'upload' view.kwargs.project_id %}">
  <span class="icon">
    <i class="fas fa-upload"></i>
  </span>
  <b>Import Data</b>
</a>
<a class="navbar-item" href="{% url 'download' view.kwargs.project_id %}">
  <span class="icon">
    <i class="fas fa-download"></i>
  </span>
  <b>Export Data</b>
</a>
{% endblock %}
{% block content %}
<div class="columns mr0">
  <aside class="column is-2 aside">
    <div>
      <div class="main">
        <a href="{% url 'dataset' view.kwargs.project_id %}" class="item">
          <span class="icon">
            <i class="fa fa-inbox"></i>
          </span>
          <span class="name">Dataset</span>
        </a>
        <a href="{% url 'label-management' view.kwargs.project_id %}" class="item">
          <span class="icon">
            <i class="fa fa-star"></i>
          </span>
          <span class="name">Labels</span>
        </a>
        <a href="{% url 'stats' view.kwargs.project_id %}" class="item">
          <span class="icon">
            <i class="fas fa-signal"></i>
          </span>
          <span class="name">Statistics</span>
        </a>
        <a href="{% url 'guideline' view.kwargs.project_id %}" class="item">
          <span class="icon">
            <i class="fas fa-book"></i>
          </span>
          <span class="name">Guideline</span>
        </a>
        <a href="{% url 'users' view.kwargs.project_id %}" class="item">
            <span class="icon">
                <i class="fas fa-users"></i>
            </span>
            <span class="name">Users</span>
        </a>
      </div>
    </div>
  </aside>
  <div class="column is-10 messages hero is-fullheight" id="message-feed">
    <div id="mail-app">
      {% block content-area %}{% endblock %}
    </div>
  </div>
</div>
{% endblock %}

{% block footer %}
{% if bundle_name %}
{% render_bundle bundle_name 'js' %}
{% endif %}
{% endblock %}
