(window.webpackJsonp=window.webpackJsonp||[]).push([[16],{256:function(e,t,n){"use strict";n.r(t),t.default={dataset:"Datensatz",actions:"Aktionen",importDataset:"Importiere Datensatz",exportDataset:"Exportiere Datensatz",text:"Text",metadata:"Metadaten",action:"Aktion",annotate:"Annotiere",importDataTitle:"Daten hochladen",importDataMessage1:"Wähle ein Dateiformat",importDataMessage2:"Wähle Datei(en)",importDataPlaceholder:"Dateieingabe",exportDataTitle:"Exportiere Daten",exportDataMessage:"Wähle ein Dateiformat",deleteDocumentsTitle:"Dokument löschen",deleteDocumentsMessage:"Bist du dir sicher, dass du die Dokumente aus dem Projekt löschen willst?",pageText:"{0}-{1} von {2}"}}}]);