(window.webpackJsonp=window.webpackJsonp||[]).push([[18],{258:function(e,n,t){"use strict";t.r(n),n.default={guideline:"Leitfaden",writeGuidelinePrompt:"Bitte schreib einen Annotationsleitfaden."}}}]);