(window.webpackJsonp=window.webpackJsonp||[]).push([[30],{267:function(t,e,n){"use strict";n.r(e),e.default={mainTitle:"Text Annotation for Humans",getStarted:"Get Started",startAnnotation:"Start Annotation",featuresTitle:"The best features",featuresTitle1:"Team Collaboration",featuresText1:"Annotation with your team mates",featuresTitle2:"Any Language",featuresText2:"Annotation with any language",featuresTitle3:"Open Source",featuresText3:"Annotation that is free and customizable",footerTitle:"Realize your ideas quickly",demoDropDown:"Try Demo",demoNER:"Named Entity Recognition",demoSent:"Sentiment Analysis",demoTranslation:"Translation",demoTextToSQL:"Text to SQL"}}}]);