(window.webpackJsonp=window.webpackJsonp||[]).push([[13],{250:function(e,t,n){"use strict";n.r(t),t.default={mainTitle:"Text-Annotation für Menschen",getStarted:"Leg los",startAnnotation:"Starte Annotation",featuresTitle:"Die besten Funktionen",featuresTitle1:"Zusammenarbeit im Team",featuresText1:"Annotiere mit Teamkollegen",featuresTitle2:"Jede Sprache",featuresText2:"Annotiere mit jeder Sprache",featuresTitle3:"Open Source",featuresText3:"Kostenlos und anpassbar",footerTitle:"Schnelles Realisieren von Ideen",demoDropDown:"Demo ausprobieren",demoNER:"Named Entity Recognition",demoSent:"Sentiment Analysis",demoTranslation:"Übersetzung",demoTextToSQL:"Text zu SQL"}}}]);