(window.webpackJsonp=window.webpackJsonp||[]).push([[92],{320:function(e,r,l){"use strict";l.r(r),r.default={colorRules:{colorRequired:"请输入颜色"},labelNameRules:{labelRequired:"请输入名称",labelLessThan30Chars:"名称必须少于30个字符"},userNameRules:{userNameRequired:"请输入用户名",userNameLessThan30Chars:"用户名必须少于30个字符"},roleRules:{roleRequired:"请输入角色"},projectNameRules:{projectNameRequired:"请输入项目名称",projectNameLessThan30Chars:"项目名称必须少于30个字符"},descriptionRules:{descriptionRequired:"请输入描述",descriptionLessThan30Chars:"描述必须少于100个字符"},projectTypeRules:{projectTypeRequired:"请输入项目类型"},fileFormatRules:{fileFormatRequired:"请输入文件类型"},uploadFileRules:{fileRequired:"请输入文件",fileLessThan1MB:"文件大小必须小于 1 MB!"},passwordRules:{passwordRequired:"请输入密码",passwordLessThan30Chars:"密码必须小于30个字符"}}}}]);