{% load static %}
{% load analytics %}
<!DOCTYPE html>
<html>
<head>
  {% google_analytics %}
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>doccano - Document Annotation Tool</title>

  <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.0.13/css/all.css" integrity="sha384-DNOHZ68U8hZfKXOrtjWvjxusGo9WQnrNx2sqG0tfsghAvtVlRW3tvkXWZh58N9jp"
    crossorigin="anonymous">
  <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,400,700" rel="stylesheet">
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bulma/0.7.1/css/bulma.min.css" crossorigin="anonymous">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma-extensions@4.0.1/bulma-divider/dist/css/bulma-divider.min.css" crossorigin="anonymous">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma-extensions@4.0.1/bulma-checkradio/dist/css/bulma-checkradio.min.css" crossorigin="anonymous">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bulma-extensions@4.0.1/bulma-tooltip/dist/css/bulma-tooltip.min.css" crossorigin="anonymous">
  <link rel="stylesheet" href="{% static 'assets/css/forum.css' %}">
  <!-- favicon settings -->
  <link rel="apple-touch-icon" sizes="57x57" href="{% static 'static/apple-icon-57x57.png' %}">
  <link rel="apple-touch-icon" sizes="60x60" href="{% static 'static/apple-icon-60x60.png' %}">
  <link rel="apple-touch-icon" sizes="72x72" href="{% static 'static/apple-icon-72x72.png' %}">
  <link rel="apple-touch-icon" sizes="76x76" href="{% static 'static/apple-icon-76x76.png' %}">
  <link rel="apple-touch-icon" sizes="114x114" href="{% static 'static/apple-icon-114x114.png' %}">
  <link rel="apple-touch-icon" sizes="120x120" href="{% static 'static/apple-icon-120x120.png' %}">
  <link rel="apple-touch-icon" sizes="144x144" href="{% static 'static/apple-icon-144x144.png' %}">
  <link rel="apple-touch-icon" sizes="152x152" href="{% static 'static/apple-icon-152x152.png' %}">
  <link rel="apple-touch-icon" sizes="180x180" href="{% static 'static/apple-icon-180x180.png' %}">
  <link rel="icon" type="image/png" sizes="192x192"  href="{% static 'static/android-icon-192x192.png' %}">
  <link rel="icon" type="image/png" sizes="32x32" href="{% static 'static/favicon-32x32.png' %}">
  <link rel="icon" type="image/png" sizes="96x96" href="{% static 'static/favicon-96x96.png' %}">
  <link rel="icon" type="image/png" sizes="16x16" href="{% static 'static/favicon-16x16.png' %}">
  <link rel="manifest" href="{% static 'static/manifest.json' %}">
  <meta name="msapplication-TileColor" content="#ffffff">
  <meta name="msapplication-TileImage" content="{% static 'static/ms-icon-144x144.png' %}">
  <meta name="theme-color" content="#ffffff">
  {% block header %}{% endblock %}
  {% azure_appinsights %}
</head>

<body>
  <nav class="navbar has-shadow">
    <div class="container">
      <div class="navbar-brand">
        <a class="navbar-item" href="{% url 'index' %}">
          <img src="{% static 'assets/images/logo.png' %}" width="32" height="32">
          <b>doccano</b>
        </a>
        <a role="button" class="navbar-burger burger" aria-label="menu" aria-expanded="false" data-target="topNav">
          <span aria-hidden="true"></span>
          <span aria-hidden="true"></span>
          <span aria-hidden="true"></span>
        </a>
        {% block navigation %}{% endblock %}
      </div>
      <div id="topNav" class="navbar-menu">
        <div class="navbar-end">
          {% if not user.is_authenticated %}
          <div class="navbar-item has-dropdown is-hoverable">
            <a class="navbar-link">
              <span>Live Demo</span>
            </a>
            <div class="navbar-dropdown">
              <a href="{% url 'demo-text-classification' %}" class="navbar-item">
                Sentiment Analysis
              </a>
              <a href="{% url 'demo-named-entity-recognition' %}" class="navbar-item">
                Named Entity Recognition
              </a>
              <a href="{% url 'demo-translation' %}" class="navbar-item">
                Translation
              </a>
            </div>
          </div>
          <a class="navbar-item" href="https://github.com/doccano/doccano">
            <span>GitHub</span>
          </a>
          {% endif %}
          {% if user.is_authenticated %}
          <a class="navbar-item" href="{% url 'projects' %}">
            <span>Projects</span>
          </a>
          {% endif %}
          {% if not user.is_authenticated %}
          <a class="navbar-item" href="{% url 'login' %}">
            <span>Login</span>
          </a>
          {% else %}
          <a class="navbar-item" href="{% url 'logout' %}">
            <span>Logout</span>
          </a>
          {% endif %}
        </div>
      </div>
    </div>
  </nav>

  {% block content %}{% endblock %}
  
  {% block footer %}{% endblock %}
</body>
</html>
