(window.webpackJsonp=window.webpackJsonp||[]).push([[53],{294:function(e,n,t){"use strict";t.r(n),n.default={home:"Accueil",welcome:"Bienvenue au Doccano!",importData:"Importer un ensemble de données",createLabels:"Créer des étiquettes pour ce projet",addMembers:"Ajouter des membres pour un travail en collaboration",defineGuideline:"Définir une ligne directrice pour le travail",annotateDataset:"Annoter un ensemble de données",viewStatistics:"Voir les statistiques",exportDataset:"Exporter l'ensemble de données"}}}]);