# Generated by Django 3.1.6 on 2021-03-02 10:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0007_auto_20210301_0302'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='guideline',
            field=models.TextField(blank=True, default=''),
        ),
    ]
